GetCodingTable: Get the information of codings
Description
Get the information of codings.Value
- A data frame:
- cidCode id
- fidFile id
- codenameCode name, in accordance with cid
- filenameFile name, in accordance with fid
- CodingLengthThe number of characters in the coding
- index1beginning index of a coding
- index2end index of a coding
Details
Codings are stored in the coding table of *.rqda file. The coding table contains necessary information, but not informative to end-users. For example, it has id of code list and file list, but not the name of them, which are stored in freecode table and source table respectively. GetCodingTable joins information from the three tables, and returns more informative data. See value section on the the returned components.