Learn R Programming

RQDA (version 0.1-6)

SummaryCoding: Summary of coding

Description

Give a summary of coding of current project.

Usage

SummaryCoding(byFile = FALSE, ...)
## S3 method for class 'SummaryCoding':
printundefined

Arguments

byFile
When it is FALSE, return the summary of current project. When it is TRUE, return the summary of coding for each coded file.
...
Other possible arguments.

Value

  • A list:
  • NumOfCodingNumber of coding for each code.
  • AvgLengthAverage number of characters in codings for each code.
  • NumOfFileNumber of files coded for each code
  • .
  • CodingOfFileNumber of codings for each file.NULL is byFile is FALSE.

See Also

GetFileId and GetCodingTable

Examples

Run this code
SummaryCoding()
SummaryCoding(FALSE)

Run the code above in your browser using DataLab