CrossCode(relation=c("overlap","inclusion","exact","proximity"),codeList=NULL,data=GetCodingTable(),print=TRUE,...)
CrossTwo(cid1, cid2,data,relation=c("overlap","inclusion","exact","proximity"),...)GetCodingTable,may be subset of the full coding table... is not used yet.CrossCode, it is a matrix. The upper matrix contains the
number of codings fitting the relation between the respective two
codes. the lower matrix is all NA. rownames of the matrix is the name of
the codes , and the colnames of the matrix is the corresponding id of
codes.
For CrossCodes, it is a numeric vector.CrossCode returns
the inter-relationship of 2 or more than 2 codes. CrossCode
make heavy use of for loops, so it may takes a while to get the result
when the coding table is large.
CrossTwo returns the summary of inter-codes relationship of two
codes based on the code id (each code id is a length-1 integer vector).relation