list.deleted shows the temporarily deleted data (deleted by
delete button, which is only tagged with deletion mark in the *.rqda file).
pdelete permanently deletes them.
CleanProject cleans the *.rqda file (call pdelete with every possible
value for the type argument).
undelete removes the temporarily deletion mark to reuse the temporarily deleted data.list.deleted(type=c("file","code","case","codecategory","filecategory"))
pdelete(type=c("file","code","case","codecategory","filecategory","coding"),ask=FALSE)
CleanProject(ask=FALSE)
undelete(type=c("file","code","case","codecategory","filecategory"),ask=TRUE)list.deleted, a data frame if there are some records with
temporarily deletion mark for the specified type.
For pdelete, CleanProject and undelete, no value is return. These
functions are used for the side-effects.list.deleted to show which ones are tagged as deleted.
By pdelete, you can permenantly delete those tagged with
temporarily deletion mark. By undelete, you can undo the
temporary deletion, the status of related elements are set back to 1.
When ask is FALSE, it will apply to all the propriate elements of
specific type. When it is TRUE, you can choose the elements of the
specific type which the action (pdelet or undelete) applies to.