Learn R Programming

RQDA (version 0.1-7)

GetAttr: Attributes

Description

Get the attributes of case or file.

Usage

GetAttr(type = c("case", "file"))
ShowSubset(x)

Arguments

type
Type of attributes.
x
an object from GetAttr

Value

  • For GetAttr, when type is "case", it is a data frame with class of "CaseAttr"; when type is "file", it is a data frame with class of "FileAttr". For ShowSubset, no value is returned, the side-effect is to change the file list or case list in respective widget.

Details

You can add and modify the attributes of cases or files. GetAttr returns this attributes as a data frame. Sometimes, you only want to show a subset of files or cases according to their attributes. You can do the subset operation of the result from GetAttr and pass it to ShowSubset.

Examples

Run this code
attr <- GetAttr("case")
ShowSubset(subset(attr,attribute1==1)) ## assuming there is a variable
named atttribute1 in attr.

Run the code above in your browser using DataLab