SearchFiles("file like '%keyword%'") ## search for files who contain the word of "keyword"
SearchFiles("file like 'keyword%'") ## search for files whose conent begin with the word of "keyword"
SearchFiles("name like '%keyword'") ## search for files whose name end with the word of "keyword"
SearchFiles("name like '%keyword one' and file like '%keyword tow%' ") ## combined conidtionsRun the code above in your browser using DataLab